"""Implementation of lpmn client."""
import argparse

from lpmn_client_biz import Connection, IOType, Task, download, upload


def get_args():
    """Parse arguments."""
    parser = argparse.ArgumentParser(
        description="LPMN CLI tool",
    )
    parser.add_argument(
        "lpmn",
        help="LPMN json query"
    )
    parser.add_argument(
        "-v",
        "--verbose",
        help="If progress should be printed.",
        action="store_true"
    )
    parser.add_argument(
        "input",
        help="Path to a input file on local machine.",
    )
    parser.add_argument(
        "-it",
        "--input-type",
        help="Type of input",
        type=IOType.argparse,
        choices=list(IOType),
        default=IOType.TEXT
    )
    parser.add_argument(
        "-o",
        "--output",
        help="Path to a output directory on local machine",
        default=''
    )
    parser.add_argument(
        "-ot",
        "--output-type",
        help="Type of input",
        type=IOType.argparse,
        choices=list(IOType),
        default=IOType.FILE
    )
    parser.add_argument(
        "-f",
        "--filename",
        help="Downloaded file name",
        default=''
    )
    parser.add_argument(
        "-t",
        "--timeout",
        help="Blocking task timeout",
        default=0,
        type=int
    )
    parser.add_argument(
        "-u",
        "--username",
        help="E-science username",
        default=''
    )
    parser.add_argument(
        "-p",
        "--password",
        help="E-science user password",
        default=''
    )
    parser.add_argument(
        "--url",
        help="Base api url",
        default=''
    )
    parser.add_argument(
        "-c",
        "--config",
        help="Path to config file",
        default=''
    )
    return parser.parse_args()


def main():
    """Runs the program."""
    task_args = get_args()
    print(task_args)
    connection = Connection(task_args.username, task_args.password,
                            task_args.url, task_args.config)
    task = Task(task_args.lpmn, connection)

    task_input = upload(connection, task_args.input) \
        if task_args.input_type == IOType.FILE \
        else task_args.input

    input_type = IOType.FILE \
        if task_args.input_type == IOType.FILE_ID \
        else task_args.input_type

    output_file_id = task.run(task_input, input_type,
                              timeout=task_args.timeout,
                              verbose=task_args.verbose)

    if task_args.output_type == IOType.FILE_ID:
        result = output_file_id
    else:
        result = download(connection,
                          file_id=output_file_id,
                          output_type=task_args.output_type,
                          output_path=task_args.output,
                          filename=task_args.filename)
    print(result)
    return result
